spoon.messaging.messaging

Package spoon :: Package messaging :: Module messaging |
[show private | hide private]
[frames | no frames]

## Module spoon.messaging.messaging

Classes
`Messaging` | This is the main messaging class that implements the basic functionality for Spoon.
`SingletonMessaging` | For convinience this is a singleton version of the Messaging system.

Function Summary
| ``send`(dst, messageStr, obj)` Shortcut for calling send on the SingletonMessaging class.

Function Details

### send(dst, messageStr, obj) Shortcut for calling send on the SingletonMessaging class. Parameters: `dst` - Destination node id `messageStr` - A string describing the message type. `obj` - Some object attached the net message.

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net